@@ -505,7 +505,7 @@ class test_evaluate(TestCase):
         # Execution order set here so as to not use too many threads
         # during the rest of the execution.  See #33 for details.
         def test_changing_nthreads_00_inc(self):
-            a = linspace(-1, 1, 1e6)
+            a = linspace(-1, 1, 1000000)
             b = ((.25 * a + .75) * a - 1.5) * a - 2
             for nthreads in range(1, 7):
                 numexpr.set_num_threads(nthreads)
@@ -513,7 +513,7 @@ class test_evaluate(TestCase):
                 assert_array_almost_equal(b, c)
 
         def test_changing_nthreads_01_dec(self):
-            a = linspace(-1, 1, 1e6)
+            a = linspace(-1, 1, 1000000)
             b = ((.25 * a + .75) * a - 1.5) * a - 2
             for nthreads in range(6, 1, -1):
                 numexpr.set_num_threads(nthreads)
@@ -967,7 +967,7 @@ class test_threading_config(TestCase):
                 "import numexpr",
                 "assert(numexpr.nthreads <= 8)",
                 "exit(0)"])
-        subprocess.check_call(['python', '-c', script])
+        subprocess.check_call([sys.executable, '-c', script])
 
     def test_max_threads_set(self):
         # Has to be done in a subprocess as `importlib.reload` doesn't let us 
@@ -978,7 +978,7 @@ class test_threading_config(TestCase):
                 "import numexpr",
                 "assert(numexpr.MAX_THREADS == 4)",
                 "exit(0)"])
-        subprocess.check_call(['python', '-c', script])
+        subprocess.check_call([sys.executable, '-c', script])
 
     def test_numexpr_num_threads(self):
         with _environment('OMP_NUM_THREADS', '5'):
